@@ -1,7 +1,7 @@
 use super::{
     arg_regular::*, method_gen::generate_arg_call_name, only_owner_gen::*, payable_gen::*, util::*,
 };
-use crate::model::Method;
+use crate::{generate::snippets, model::Method};
 
 pub fn generate_call_to_method_expr(m: &Method) -> proc_macro2::TokenStream {
     let fn_ident = &m.name;
@@ -32,6 +32,7 @@ pub fn generate_call_method_body(m: &Method) -> proc_macro2::TokenStream {
 }
 
 pub fn generate_call_method_body_fixed_args(m: &Method) -> proc_macro2::TokenStream {
+    let api_static_init = snippets::call_method_api_static_init();
     let payable_snippet = generate_payable_snippet(m);
     let only_owner_snippet = generate_only_owner_snippet(m);
 
@@ -63,15 +64,19 @@ pub fn generate_call_method_body_fixed_args(m: &Method) -> proc_macro2::TokenStr
     let nr_args = arg_index + 1;
 
     quote! {
+        #api_static_init
         #payable_snippet
         #only_owner_snippet
-        elrond_wasm::api::EndpointArgumentApi::check_num_arguments(&self.raw_vm_api(), #nr_args);
+        elrond_wasm::api::EndpointArgumentApiImpl::check_num_arguments(
+            &<Self::Api as elrond_wasm::api::EndpointArgumentApi>::argument_api_impl(),
+            #nr_args);
         #(#arg_init_snippets)*
         #body_with_result
     }
 }
 
 fn generate_call_method_body_variable_nr_args(m: &Method) -> proc_macro2::TokenStream {
+    let api_static_init = snippets::call_method_api_static_init();
     let payable_snippet = generate_payable_snippet(m);
     let only_owner_snippet = generate_only_owner_snippet(m);
 
@@ -91,11 +96,13 @@ fn generate_call_method_body_variable_nr_args(m: &Method) -> proc_macro2::TokenS
     let body_with_result = generate_body_with_result(&m.return_type, &call);
 
     quote! {
+        #api_static_init
+
         #payable_snippet
 
         #only_owner_snippet
 
-        let mut ___arg_loader = EndpointDynArgLoader::new(self.raw_vm_api());
+        let mut ___arg_loader = elrond_wasm::io::EndpointDynArgLoader::<Self::Api>::new();
 
         #(#arg_init_snippets)*
 
@@ -116,7 +123,7 @@ pub fn generate_body_with_result(
         syn::ReturnType::Type(_, _) => {
             quote! {
                 let result = #mbody;
-                elrond_wasm::io::EndpointResult::finish(&result, self.raw_vm_api());
+                elrond_wasm::io::EndpointResult::finish::<Self::Api>(&result);
             }
         },
     }
